@@ -65,8 +65,9 @@ void Audio::threadFinished()
     connect(music, SIGNAL(finished()), this, SLOT(audioFinished()));
 
     audioFile->close();
+    this->wavCreated();
 
-    reader->deleteLater();
+ //   reader->deleteLater();
 }
 
 void Audio::audioFinished()
