@@ -21,6 +21,7 @@ MainWindow::MainWindow(QWidget *parent)
     options = new Options(this);
     options->hide();
     network = new Network();
+    openPlaylist = false;
 
     message = new QProgressDialog("", "Cancel", 0, -1, this);
 
@@ -265,9 +266,16 @@ void MainWindow::playlist_selected(QList<QTreeWidgetItem *> items, int column)
     QTreeWidgetItem *item;
     foreach (item, items)
     {
+        openPlaylist = true;
+        if (item == items.takeFirst())
+            openPlaylist = false;
+        else
+            openPlaylist = true;
         bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  item->text(column).toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
         network->retrieveArticle(item->text(column), existsAlready);
+
     }
+    openPlaylist = false;
     player->setPlaylistFocus();
 }
 
@@ -291,7 +299,7 @@ void MainWindow::newSearch(QString keyword)
 void MainWindow::openArticleInPlayer(QString title, QString article)
 {
      message->setLabelText("Processing " + title);
-     player->openArticle(title, article);
+     player->openArticle(title, article, openPlaylist);
      ui->playerButton->setDown(true);
      player->show();
 
