@@ -24,7 +24,7 @@ Player::~Player()
     delete ui;
 }
 
-void Player::openArticle(QString itemName, QString text)
+void Player::openArticle(QString itemName, QString text, bool playlist)
 {
     path = QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + itemName.toLower().normalized(QString::NormalizationForm_D)+".txt";
 
@@ -64,7 +64,8 @@ void Player::openArticle(QString itemName, QString text)
 
     ui->articleBrowser->setText(text);
 
-    audio->createWav(path);
+    if (!playlist)
+        audio->createWav(path);
 
     articleLoaded = true;
 
