@@ -14,7 +14,7 @@ public:
     QStringList getPlaylistContent(QString title);
     void addNewItemToPlaylist(QString title, QString item);
     void removePlaylist(QString title);
-    void removePlaylistItem(QTreeWidgetItem *item, int column, QTreeWidgetItem *parent);
+    void removePlaylistItem(QString item,int column, QTreeWidgetItem *parent);
 
 private:
     QMap<QString, QStringList> playlists;
